@@ -12,6 +12,7 @@ def search(name=None, source=None, id_No=None):
     """
     from sqlalchemy import create_engine
     from sqlalchemy import text
+    import warnings
     import pandas as pd
     cluster_arn = 'arn:aws:rds:us-east-2:003707765429:cluster:esip-global-lake-level'
     secret_arn = 'arn:aws:secretsmanager:us-east-2:003707765429:secret:esip-lake-level-enduser-qugKfY'
@@ -36,12 +37,12 @@ def search(name=None, source=None, id_No=None):
         df_lake = pd.read_sql('SELECT * FROM reference_ID WHERE MATCH (lake_name) AGAINST (:name IN NATURAL LANGUAGE '
                               'MODE) LIMIT 0, 5',
                               con=sql_engine, params={'name': safe_name})
-
+    sql_engine.close()
     if len(df_lake) < 1:
         raise RuntimeError('No results returned. Please adjust search parameters or see documentation')
     if len(df_lake) > 1:
-        print('Search Result: \'{}\' has more than 1 Result. Showing the {} most relevant results.\n'
-              'Specify \'id_No\' or narrow search name.'.format(safe_name, len(df_lake)))
+        warnings.warn('Search Result: \'{}\' has more than 1 Result. Showing the {} most relevant results.\n'
+              'Specify \'id_No\' or narrow search name.'.format(safe_name, len(df_lake)), category = RuntimeWarning)
         print(df_lake.filter(['id_No', 'source', 'lake_name']).to_markdown())
 
     elif len(df_lake) == 1:
@@ -54,10 +55,9 @@ def search(name=None, source=None, id_No=None):
                                how='outer').drop('metadata', axis=1)
         print(df_unpacked.to_markdown())
         lake_object = _lake_meta_constructor(df_unpacked)
-
         return lake_object
 
-    sql_engine.close()
+
 
 
 def _lake_meta_constructor(df):
@@ -162,6 +162,7 @@ def _lake_meta_constructor(df):
                         dataframe = dataframe,
                         data = None)
             lake.data = _get_levels(lake)
+            sql_engine.close()
             return lake
 def _get_levels(lake):
     """
@@ -200,6 +201,7 @@ def _get_levels(lake):
         df_list.append(search_df)
         _printProgressBar(count + 1, len(space), prefix = 'Building Lake', suffix = 'Complete', length = 50)
     df = pd.concat(df_list).sort_values('date')
+    sql_engine.close()
     return df
 
 
@@ -273,7 +275,10 @@ class Lake(object):
         gdf.plot(*args, **kwargs, alpha=.5, ax=ax, color='red', aspect = 'equal')
         ax.set_xlim(minx, maxx)
         ax.set_ylim(miny, maxy)
-        ctx.add_basemap(ax, source = ctx.providers.OpenTopoMap, crs = 'EPSG:4326', **{'zoom': zoom})
+        if zoom:
+            ctx.add_basemap(ax, source = ctx.providers.OpenTopoMap, crs = 'EPSG:4326', zoom=zoom)
+        else:
+            ctx.add_basemap(ax, source = ctx.providers.OpenTopoMap, crs = 'EPSG:4326')
         ax.set_title(self.id_No.astype(str) + " : " + self.name)
         if out_path:
             plt.savefig(out_path)
